### CM tutorial

https://github.com/mlcommons/ck/blob/master/docs/tutorials/scc23-mlperf-inference-bert.md

### Challenge

Reproduce and optimize MLPerf inference benchmarks during Student Cluster Competition at SuperComputing'23.

See our [related challange from 2022]()https://access.cknowledge.org/playground/?action=challenges&name=repro-mlperf-inference-retinanet-scc2022).

### Organizers

* [MLCommons taskforce on automation and reproducibility](https://cKnowledge.org/mlcommons-taskforce)
* [cTuning foundation](https://cTuning.org)
* [cKnowledge.org](https://cKnowledge.org)

